@@ -31,4 +31,9 @@ STATIC_URL = setting_overrides.get(
 REACT_EXTERNAL = setting_overrides.get(
     'REACT_EXTERNAL',
     'window.React',
+)
+
+DEBUG = setting_overrides.get(
+    'DEBUG',
+    settings.DEBUG,
 )
\ No newline at end of file
